@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.4.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -61,24 +65,30 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "surveytargetexpressionparser.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 1 "surveytargetexpressionparser.y"
 
 /*
     Copyright (C) 2017 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+    Permission is hereby granted, free of charge, to any person obtaining
+    a copy of this software and associated documentation files (the
+    "Software"), to deal in the Software without restriction, including
+    without limitation the rights to use, copy, modify, merge, publish,
+    distribute, sublicense, and/or sell copies of the Software, and to
+    permit persons to whom the Software is furnished to do so, subject to
+    the following conditions:
 
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
+    The above copyright notice and this permission notice shall be included
+    in all copies or substantial portions of the Software.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 
 #include "surveytargetexpression.h"
@@ -97,13 +107,17 @@ void yyerror(KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanne
 }
 
 
-#line 101 "surveytargetexpressionparser_p.cpp" /* yacc.c:339  */
+#line 111 "surveytargetexpressionparser_p.cpp"
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -115,8 +129,8 @@ void yyerror(KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanne
 # define YYERROR_VERBOSE 0
 #endif
 
-/* In a future release of Bison, this section will be replaced
-   by #include "surveytargetexpressionparser_p.h".  */
+/* Use api.header.include to #include this header
+   instead of duplicating it here.  */
 #ifndef YY_YY_SURVEYTARGETEXPRESSIONPARSER_P_H_INCLUDED
 # define YY_YY_SURVEYTARGETEXPRESSIONPARSER_P_H_INCLUDED
 /* Debug traces.  */
@@ -127,7 +141,7 @@ void yyerror(KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanne
 extern int yydebug;
 #endif
 /* "%code requires" blocks.  */
-#line 36 "surveytargetexpressionparser.y" /* yacc.c:355  */
+#line 42 "surveytargetexpressionparser.y"
 
 
 #ifndef YY_TYPEDEF_YY_SCANNER_T
@@ -136,7 +150,7 @@ typedef void* yyscan_t;
 #endif
 
 
-#line 140 "surveytargetexpressionparser_p.cpp" /* yacc.c:355  */
+#line 154 "surveytargetexpressionparser_p.cpp"
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -166,10 +180,9 @@ typedef void* yyscan_t;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 50 "surveytargetexpressionparser.y" /* yacc.c:355  */
+#line 56 "surveytargetexpressionparser.y"
 
     int intVal;
     double doubleVal;
@@ -177,9 +190,9 @@ union YYSTYPE
     char *str;
     KUserFeedback::SurveyTargetExpression *expression;
 
-#line 181 "surveytargetexpressionparser_p.cpp" /* yacc.c:355  */
-};
+#line 194 "surveytargetexpressionparser_p.cpp"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
@@ -191,9 +204,7 @@ int yyparse (KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanne
 
 #endif /* !YY_YY_SURVEYTARGETEXPRESSIONPARSER_P_H_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 197 "surveytargetexpressionparser_p.cpp" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -214,13 +225,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -232,7 +243,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -268,15 +279,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -284,7 +286,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -304,6 +306,8 @@ typedef short int yytype_int16;
 #endif
 
 
+#define YY_ASSERT(E) ((void) (0 && (E)))
+
 #if ! defined yyoverflow || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
@@ -446,16 +450,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  41
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   275
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -492,8 +496,8 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    90,    90,    93,    94,    95,    96,    99,   100,   101,
-     102,   103,   104,   107,   112,   117,   123,   124,   125,   126
+       0,    96,    96,    99,   100,   101,   102,   105,   106,   107,
+     108,   109,   110,   113,   118,   123,   129,   130,   131,   132
 };
 #endif
 
@@ -625,22 +629,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (expression, scanner, YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (expression, scanner, YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -680,39 +684,39 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanner)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanner)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (expression);
   YYUSE (scanner);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanner)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanner)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, expression, scanner);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, expression, scanner);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -746,7 +750,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, KUserFeedback::SurveyTargetExpression **expression, yyscan_t scanner)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -757,7 +761,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, KUserFeedback:
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               , expression, scanner);
       YYFPRINTF (stderr, "\n");
     }
@@ -861,7 +865,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -879,7 +886,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -957,10 +964,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -972,6 +979,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -983,9 +991,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1036,37 +1045,36 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, KUserFeedback::Sur
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   switch (yytype)
     {
-          case 19: /* T_STRING  */
-#line 84 "surveytargetexpressionparser.y" /* yacc.c:1257  */
+    case 19: /* T_STRING  */
+#line 90 "surveytargetexpressionparser.y"
       { free(((*yyvaluep).str)); }
-#line 1043 "surveytargetexpressionparser_p.cpp" /* yacc.c:1257  */
+#line 1052 "surveytargetexpressionparser_p.cpp"
         break;
 
     case 20: /* T_IDENTIFIER  */
-#line 84 "surveytargetexpressionparser.y" /* yacc.c:1257  */
+#line 90 "surveytargetexpressionparser.y"
       { free(((*yyvaluep).str)); }
-#line 1049 "surveytargetexpressionparser_p.cpp" /* yacc.c:1257  */
+#line 1058 "surveytargetexpressionparser_p.cpp"
         break;
 
     case 23: /* Expr  */
-#line 85 "surveytargetexpressionparser.y" /* yacc.c:1257  */
+#line 91 "surveytargetexpressionparser.y"
       { delete ((*yyvaluep).expression); }
-#line 1055 "surveytargetexpressionparser_p.cpp" /* yacc.c:1257  */
+#line 1064 "surveytargetexpressionparser_p.cpp"
         break;
 
     case 24: /* Term  */
-#line 85 "surveytargetexpressionparser.y" /* yacc.c:1257  */
+#line 91 "surveytargetexpressionparser.y"
       { delete ((*yyvaluep).expression); }
-#line 1061 "surveytargetexpressionparser_p.cpp" /* yacc.c:1257  */
+#line 1070 "surveytargetexpressionparser_p.cpp"
         break;
 
     case 25: /* Value  */
-#line 85 "surveytargetexpressionparser.y" /* yacc.c:1257  */
+#line 91 "surveytargetexpressionparser.y"
       { delete ((*yyvaluep).expression); }
-#line 1067 "surveytargetexpressionparser_p.cpp" /* yacc.c:1257  */
+#line 1076 "surveytargetexpressionparser_p.cpp"
         break;
 
-
       default:
         break;
     }
@@ -1152,23 +1160,33 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1184,14 +1202,10 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1207,35 +1221,33 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
-
-  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   if (yystate == YYFINAL)
     YYACCEPT;
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1293,7 +1305,6 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
-
   goto yynewstate;
 
 
@@ -1308,7 +1319,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1328,129 +1339,130 @@ yyreduce:
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
-        case 2:
-#line 90 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+  case 2:
+#line 96 "surveytargetexpressionparser.y"
     { *expression = (yyvsp[0].expression); }
-#line 1335 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1346 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 3:
-#line 93 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 99 "surveytargetexpressionparser.y"
     { printf("TERM "); (yyval.expression) = (yyvsp[0].expression); }
-#line 1341 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1352 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 4:
-#line 94 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 100 "surveytargetexpressionparser.y"
     { (yyval.expression) = (yyvsp[-1].expression); }
-#line 1347 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1358 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 5:
-#line 95 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 101 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpLogicAnd, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1353 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1364 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 6:
-#line 96 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 102 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpLogicOr, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1359 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1370 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 7:
-#line 99 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 105 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpEqual, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1365 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1376 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 8:
-#line 100 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 106 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpNotEqual, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1371 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1382 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 9:
-#line 101 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 107 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpGreater, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1377 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1388 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 10:
-#line 102 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 108 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpGreaterEqual, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1383 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1394 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 11:
-#line 103 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 109 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpLess, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1389 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1400 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 12:
-#line 104 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 110 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(SurveyTargetExpression::OpLessEqual, (yyvsp[-2].expression), (yyvsp[0].expression)); }
-#line 1395 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1406 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 13:
-#line 107 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 113 "surveytargetexpressionparser.y"
     {
         (yyval.expression) = new SurveyTargetExpression(QString::fromUtf8((yyvsp[-2].str)), QVariant(), QString::fromUtf8((yyvsp[0].str)));
         free((yyvsp[-2].str));
         free((yyvsp[0].str));
     }
-#line 1405 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1416 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 14:
-#line 112 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 118 "surveytargetexpressionparser.y"
     {
         (yyval.expression) = new SurveyTargetExpression(QString::fromUtf8((yyvsp[-5].str)), (yyvsp[-3].intVal), QString::fromUtf8((yyvsp[0].str)));
         free((yyvsp[-5].str));
         free((yyvsp[0].str));
     }
-#line 1415 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1426 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 15:
-#line 117 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 123 "surveytargetexpressionparser.y"
     {
         (yyval.expression) = new SurveyTargetExpression(QString::fromUtf8((yyvsp[-5].str)), QString::fromUtf8((yyvsp[-3].str)), QString::fromUtf8((yyvsp[0].str)));
         free((yyvsp[-5].str));
         free((yyvsp[-3].str));
         free((yyvsp[0].str));
     }
-#line 1426 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1437 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 16:
-#line 123 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 129 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression((yyvsp[0].doubleVal)); }
-#line 1432 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1443 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 17:
-#line 124 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 130 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression((yyvsp[0].intVal)); }
-#line 1438 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1449 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 18:
-#line 125 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 131 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression((yyvsp[0].boolVal)); }
-#line 1444 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1455 "surveytargetexpressionparser_p.cpp"
     break;
 
   case 19:
-#line 126 "surveytargetexpressionparser.y" /* yacc.c:1646  */
+#line 132 "surveytargetexpressionparser.y"
     { (yyval.expression) = new SurveyTargetExpression(QString::fromUtf8((yyvsp[0].str))); free((yyvsp[0].str)); }
-#line 1450 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1461 "surveytargetexpressionparser_p.cpp"
     break;
 
 
-#line 1454 "surveytargetexpressionparser_p.cpp" /* yacc.c:1646  */
+#line 1465 "surveytargetexpressionparser_p.cpp"
+
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1475,14 +1487,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1565,12 +1576,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1632,6 +1641,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1639,6 +1649,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1649,6 +1660,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1678,5 +1693,5 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 129 "surveytargetexpressionparser.y" /* yacc.c:1906  */
+#line 135 "surveytargetexpressionparser.y"
 
