@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,7 +45,7 @@ class GAMMARAY_LAUNCHER_UI_EXPORT LauncherWindow : public QDialog
     Q_OBJECT
 public:
     explicit LauncherWindow(QWidget *parent = nullptr);
-    ~LauncherWindow();
+    ~LauncherWindow() override;
 
     /// returns all information required to perform the launch/attach
     LaunchOptions launchOptions() const;
