@@ -59,6 +59,7 @@
 #include <QPalette>
 #include <QPen>
 #include <QTextFormat>
+#include <QTimer>
 
 using namespace GammaRay;
 
@@ -138,7 +139,9 @@ GuiSupport::GuiSupport(Probe *probe, QObject *parent)
     connect(m_probe, &Probe::objectCreated, this, &GuiSupport::objectCreated);
 
     if (auto guiApp = qobject_cast<QGuiApplication*>(QCoreApplication::instance())) {
-        updateWindowIcon();
+        QTimer::singleShot(0, this, [this]() {
+            updateWindowIcon();
+        });
 
         m_probe->installGlobalEventFilter(this);
         foreach (auto w, guiApp->topLevelWindows()) {
