@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -71,6 +71,7 @@
 #include <Qt3DCore/QTransform>
 
 #include <QDebug>
+#include <QOpenGLContext>
 #include <QUrl>
 #include <QToolBar>
 #include <QWindow>
@@ -95,6 +96,7 @@ Qt3DGeometryTab::Qt3DGeometryTab(PropertyWidget *parent)
     , m_aspectEngine(nullptr)
     , m_camera(nullptr)
     , m_geometryRenderer(nullptr)
+    , m_es2lineRenderer(nullptr)
     , m_geometryTransform(nullptr)
     , m_cullMode(nullptr)
     , m_depthTest(nullptr)
@@ -173,17 +175,13 @@ Qt3DGeometryTab::Qt3DGeometryTab(PropertyWidget *parent)
     m_surface = new QWindow;
     m_surface->setFlags(Qt::Window | Qt::FramelessWindowHint);
     m_surface->setSurfaceType(QSurface::OpenGLSurface);
-    QSurfaceFormat format;
-    format.setDepthBufferSize(24);
-    format.setSamples(4); // ???
-    format.setStencilBufferSize(8); // ???
-    format.setMajorVersion(3);
-    format.setMinorVersion(3);
-    format.setProfile(QSurfaceFormat::CoreProfile);
+    const auto format = probeFormat();
     m_surface->setFormat(format);
     QSurfaceFormat::setDefaultFormat(format);
     m_surface->create();
-    ui->geometryPage->layout()->addWidget(QWidget::createWindowContainer(m_surface, this));
+    auto container = QWidget::createWindowContainer(m_surface, this);
+    container->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    ui->geometryPage->layout()->addWidget(container);
     m_surface->installEventFilter(this);
 
     m_interface = ObjectBroker::object<Qt3DGeometryExtensionInterface *>(
@@ -192,9 +190,7 @@ Qt3DGeometryTab::Qt3DGeometryTab(PropertyWidget *parent)
             &Qt3DGeometryTab::updateGeometry);
 }
 
-Qt3DGeometryTab::~Qt3DGeometryTab()
-{
-}
+Qt3DGeometryTab::~Qt3DGeometryTab() = default;
 
 bool Qt3DGeometryTab::eventFilter(QObject *receiver, QEvent *event)
 {
@@ -246,6 +242,23 @@ bool Qt3DGeometryTab::eventFilter(QObject *receiver, QEvent *event)
     auto picker = new Qt3DRender::QObjectPicker;
     connect(picker, &Qt3DRender::QObjectPicker::clicked, this, &Qt3DGeometryTab::trianglePicked);
     geometryEntity->addComponent(picker);
+
+    // fallback wireframe rendering with ES2
+    if (m_usingES2Fallback) {
+        auto es2lineEntity = new Qt3DCore::QEntity(rootEntity);
+        m_es2lineRenderer = new Qt3DRender::QGeometryRenderer;
+        es2lineEntity->addComponent(m_es2lineRenderer);
+        es2lineEntity->addComponent(createES2WireframeMaterial(rootEntity));
+        es2lineEntity->addComponent(m_geometryTransform);
+
+        auto label = new QLabel(tr("<i>Using OpenGL ES2 fallback, wireframe rendering will be inaccurate.</i>"));
+        label->setAlignment(Qt::AlignRight);
+        label->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
+        ui->geometryPage->layout()->addWidget(label);
+
+        ui->actionShowNormals->setToolTip(tr("Visualizing normals not available when running in OpenGL ES2 fallback mode."));
+    }
+
     updateGeometry();
 
     auto lightEntity = new Qt3DCore::QEntity(rootEntity);
@@ -275,37 +288,40 @@ Qt3DCore::QComponent *Qt3DGeometryTab::createMaterial(Qt3DCore::QNode *parent)
     auto material = new Qt3DRender::QMaterial(parent);
 
     // wireframe render pass
+    m_cullMode = new Qt3DRender::QCullFace;
+    m_cullMode->setMode(ui->actionCullBack->isChecked() ? Qt3DRender::QCullFace::Back : Qt3DRender::QCullFace::NoCulling);
+
     m_shadingMode = new Qt3DRender::QParameter(QStringLiteral("shadingMode"), m_shadingModeCombo->currentData(), material);
     material->addParameter(m_shadingMode);
-    auto wireframeShader = new Qt3DRender::QShaderProgram;
-    wireframeShader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral(
-                                                                                         "qrc:/gammaray/qt3dinspector/geometryextension/wireframe.vert"))));
-    wireframeShader->setGeometryShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(
-                                                                                      QStringLiteral(
-                                                                                          "qrc:/gammaray/qt3dinspector/geometryextension/wireframe.geom"))));
-    wireframeShader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(
-                                                                                      QStringLiteral(
-                                                                                          "qrc:/gammaray/qt3dinspector/geometryextension/wireframe.frag"))));
 
-    auto wireframeRenderPass = new Qt3DRender::QRenderPass;
-    wireframeRenderPass->setShaderProgram(wireframeShader);
-    m_cullMode = new Qt3DRender::QCullFace(wireframeRenderPass);
-    m_cullMode->setMode(
-        ui->actionCullBack->isChecked() ? Qt3DRender::QCullFace::Back : Qt3DRender::QCullFace::NoCulling);
-    wireframeRenderPass->addRenderState(m_cullMode);
+    auto gl3WireframeShader = new Qt3DRender::QShaderProgram;
+    gl3WireframeShader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/gl3/wireframe.vert"))));
+    gl3WireframeShader->setGeometryShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/gl3/wireframe.geom"))));
+    gl3WireframeShader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/gl3/wireframe.frag"))));
+    auto es2WireframeShader = new Qt3DRender::QShaderProgram;
+    es2WireframeShader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/es2/surface.vert"))));
+    es2WireframeShader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/es2/surface.frag"))));
 
-    auto blendEquationArgs = new Qt3DRender::QBlendEquationArguments(wireframeRenderPass);
+    auto blendEquationArgs = new Qt3DRender::QBlendEquationArguments;
     blendEquationArgs->setSourceRgb(Qt3DRender::QBlendEquationArguments::SourceAlpha);
     blendEquationArgs->setDestinationRgb(Qt3DRender::QBlendEquationArguments::OneMinusSourceAlpha);
-    wireframeRenderPass->addRenderState(blendEquationArgs);
-    auto blendEquation = new Qt3DRender::QBlendEquation(wireframeRenderPass);
+    auto blendEquation = new Qt3DRender::QBlendEquation;
     blendEquation->setBlendFunction(Qt3DRender::QBlendEquation::Add);
-    wireframeRenderPass->addRenderState(blendEquation);
-
-    m_depthTest = new Qt3DRender::QDepthTest(wireframeRenderPass);
+    m_depthTest = new Qt3DRender::QDepthTest;
     m_depthTest->setDepthFunction(Qt3DRender::QDepthTest::Less);
-    wireframeRenderPass->addRenderState(m_depthTest);
 
+    auto gl3WireframeRenderPass = new Qt3DRender::QRenderPass;
+    gl3WireframeRenderPass->setShaderProgram(gl3WireframeShader);
+    gl3WireframeRenderPass->addRenderState(m_cullMode);
+    gl3WireframeRenderPass->addRenderState(blendEquationArgs);
+    gl3WireframeRenderPass->addRenderState(blendEquation);
+    gl3WireframeRenderPass->addRenderState(m_depthTest);
+    auto es2WireframeRenderPass = new Qt3DRender::QRenderPass;
+    es2WireframeRenderPass->setShaderProgram(es2WireframeShader);
+    es2WireframeRenderPass->addRenderState(m_cullMode);
+    es2WireframeRenderPass->addRenderState(blendEquationArgs);
+    es2WireframeRenderPass->addRenderState(blendEquation);
+    es2WireframeRenderPass->addRenderState(m_depthTest);
 
     // normal render pass
     m_normalLength = new Qt3DRender::QParameter(QStringLiteral("normalLength"), 0.1, material);
@@ -313,11 +329,11 @@ Qt3DCore::QComponent *Qt3DGeometryTab::createMaterial(Qt3DCore::QNode *parent)
 
     auto normalsShader = new Qt3DRender::QShaderProgram;
     normalsShader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral(
-                                                                                       "qrc:/gammaray/qt3dinspector/geometryextension/passthrough.vert"))));
+                                                                                       "qrc:/gammaray/qt3dinspector/geometryextension/gl3/passthrough.vert"))));
     normalsShader->setGeometryShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral(
-                                                                                         "qrc:/gammaray/qt3dinspector/geometryextension/normals.geom"))));
+                                                                                         "qrc:/gammaray/qt3dinspector/geometryextension/gl3/normals.geom"))));
     normalsShader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral(
-                                                                                         "qrc:/gammaray/qt3dinspector/geometryextension/normals.frag"))));
+                                                                                         "qrc:/gammaray/qt3dinspector/geometryextension/gl3/normals.frag"))));
 
     m_normalsRenderPass = new Qt3DRender::QRenderPass;
     m_normalsRenderPass->setShaderProgram(normalsShader);
@@ -327,13 +343,53 @@ Qt3DCore::QComponent *Qt3DGeometryTab::createMaterial(Qt3DCore::QNode *parent)
     filterKey->setName(QStringLiteral("renderingStyle"));
     filterKey->setValue(QStringLiteral("forward"));
 
+    auto gl3Technique = new Qt3DRender::QTechnique;
+    gl3Technique->graphicsApiFilter()->setApi(Qt3DRender::QGraphicsApiFilter::OpenGL);
+    gl3Technique->graphicsApiFilter()->setMajorVersion(3);
+    gl3Technique->graphicsApiFilter()->setMinorVersion(3);
+    gl3Technique->graphicsApiFilter()->setProfile(Qt3DRender::QGraphicsApiFilter::CoreProfile);
+    gl3Technique->addRenderPass(gl3WireframeRenderPass);
+    gl3Technique->addRenderPass(m_normalsRenderPass);
+    gl3Technique->addFilterKey(filterKey);
+    auto es2Technique = new Qt3DRender::QTechnique;
+    es2Technique->graphicsApiFilter()->setApi(Qt3DRender::QGraphicsApiFilter::OpenGLES);
+    es2Technique->graphicsApiFilter()->setMajorVersion(2);
+    es2Technique->graphicsApiFilter()->setMinorVersion(0);
+    es2Technique->graphicsApiFilter()->setProfile(Qt3DRender::QGraphicsApiFilter::NoProfile);
+    es2Technique->addRenderPass(es2WireframeRenderPass);
+    es2Technique->addFilterKey(filterKey);
+
+    auto effect = new Qt3DRender::QEffect;
+    effect->addTechnique(gl3Technique);
+    effect->addTechnique(es2Technique);
+
+    material->setEffect(effect);
+    return material;
+}
+
+Qt3DCore::QComponent* Qt3DGeometryTab::createES2WireframeMaterial(Qt3DCore::QNode *parent)
+{
+    auto material = new Qt3DRender::QMaterial(parent);
+
+    auto shader = new Qt3DRender::QShaderProgram;
+    shader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/es2/wireframe.vert"))));
+    shader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/es2/wireframe.frag"))));
+
+    auto renderPass = new Qt3DRender::QRenderPass;
+    renderPass->setShaderProgram(shader);
+    renderPass->addRenderState(m_cullMode);
+    renderPass->addRenderState(m_depthTest);
+
+    auto filterKey = new Qt3DRender::QFilterKey(material);
+    filterKey->setName(QStringLiteral("renderingStyle"));
+    filterKey->setValue(QStringLiteral("forward"));
+
     auto technique = new Qt3DRender::QTechnique;
-    technique->graphicsApiFilter()->setApi(Qt3DRender::QGraphicsApiFilter::OpenGL);
-    technique->graphicsApiFilter()->setMajorVersion(3);
-    technique->graphicsApiFilter()->setMinorVersion(3);
-    technique->graphicsApiFilter()->setProfile(Qt3DRender::QGraphicsApiFilter::CoreProfile);
-    technique->addRenderPass(wireframeRenderPass);
-    technique->addRenderPass(m_normalsRenderPass);
+    technique->graphicsApiFilter()->setApi(Qt3DRender::QGraphicsApiFilter::OpenGLES);
+    technique->graphicsApiFilter()->setMajorVersion(2);
+    technique->graphicsApiFilter()->setMinorVersion(0);
+    technique->graphicsApiFilter()->setProfile(Qt3DRender::QGraphicsApiFilter::NoProfile);
+    technique->addRenderPass(renderPass);
     technique->addFilterKey(filterKey);
 
     auto effect = new Qt3DRender::QEffect;
@@ -347,36 +403,49 @@ Qt3DCore::QComponent *Qt3DGeometryTab::createSkyboxMaterial(Qt3DCore::QNode *par
 {
     auto material = new Qt3DRender::QMaterial(parent);
 
-    auto shader = new Qt3DRender::QShaderProgram;
-    shader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral(
-                                                                                "qrc:/gammaray/qt3dinspector/geometryextension/skybox.vert"))));
-    shader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral(
-                                                                                  "qrc:/gammaray/qt3dinspector/geometryextension/skybox.frag"))));
-
     auto cullFront = new Qt3DRender::QCullFace;
     cullFront->setMode(Qt3DRender::QCullFace::Front);
     auto depthTest = new Qt3DRender::QDepthTest;
     depthTest->setDepthFunction(Qt3DRender::QDepthTest::LessOrEqual);
 
-    auto renderPass = new Qt3DRender::QRenderPass;
-    renderPass->setShaderProgram(shader);
-    renderPass->addRenderState(cullFront);
-    renderPass->addRenderState(depthTest);
+    auto gl3Shader = new Qt3DRender::QShaderProgram;
+    gl3Shader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/gl3/skybox.vert"))));
+    gl3Shader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/gl3/skybox.frag"))));
+    auto es2Shader = new Qt3DRender::QShaderProgram;
+    es2Shader->setVertexShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/es2/skybox.vert"))));
+    es2Shader->setFragmentShaderCode(Qt3DRender::QShaderProgram::loadSource(QUrl(QStringLiteral("qrc:/gammaray/qt3dinspector/geometryextension/es2/skybox.frag"))));
+
+    auto gl3RenderPass = new Qt3DRender::QRenderPass;
+    gl3RenderPass->setShaderProgram(gl3Shader);
+    gl3RenderPass->addRenderState(cullFront);
+    gl3RenderPass->addRenderState(depthTest);
+    auto es2RenderPass = new Qt3DRender::QRenderPass;
+    es2RenderPass->setShaderProgram(es2Shader);
+    es2RenderPass->addRenderState(cullFront);
+    es2RenderPass->addRenderState(depthTest);
 
     auto filterKey = new Qt3DRender::QFilterKey(material);
     filterKey->setName(QStringLiteral("renderingStyle"));
     filterKey->setValue(QStringLiteral("forward"));
 
-    auto technique = new Qt3DRender::QTechnique;
-    technique->graphicsApiFilter()->setApi(Qt3DRender::QGraphicsApiFilter::OpenGL);
-    technique->graphicsApiFilter()->setMajorVersion(3);
-    technique->graphicsApiFilter()->setMinorVersion(3);
-    technique->graphicsApiFilter()->setProfile(Qt3DRender::QGraphicsApiFilter::CoreProfile);
-    technique->addRenderPass(renderPass);
-    technique->addFilterKey(filterKey);
+    auto gl3Technique = new Qt3DRender::QTechnique;
+    gl3Technique->graphicsApiFilter()->setApi(Qt3DRender::QGraphicsApiFilter::OpenGL);
+    gl3Technique->graphicsApiFilter()->setMajorVersion(3);
+    gl3Technique->graphicsApiFilter()->setMinorVersion(3);
+    gl3Technique->graphicsApiFilter()->setProfile(Qt3DRender::QGraphicsApiFilter::CoreProfile);
+    gl3Technique->addRenderPass(gl3RenderPass);
+    gl3Technique->addFilterKey(filterKey);
+    auto es2Technique = new Qt3DRender::QTechnique;
+    es2Technique->graphicsApiFilter()->setApi(Qt3DRender::QGraphicsApiFilter::OpenGLES);
+    es2Technique->graphicsApiFilter()->setMajorVersion(2);
+    es2Technique->graphicsApiFilter()->setMinorVersion(0);
+    es2Technique->graphicsApiFilter()->setProfile(Qt3DRender::QGraphicsApiFilter::NoProfile);
+    es2Technique->addRenderPass(es2RenderPass);
+    es2Technique->addFilterKey(filterKey);
 
     auto effect = new Qt3DRender::QEffect;
-    effect->addTechnique(technique);
+    effect->addTechnique(gl3Technique);
+    effect->addTechnique(es2Technique);
 
     material->setEffect(effect);
     return material;
@@ -437,7 +506,7 @@ void Qt3DGeometryTab::updateGeometry()
             setupAttribute(normalAttr, attrData);
             normalAttr->setName(Qt3DRender::QAttribute::defaultNormalAttributeName());
             geometry->addAttribute(normalAttr);
-            ui->actionShowNormals->setEnabled(true);
+            ui->actionShowNormals->setEnabled(!m_usingES2Fallback);
             m_shadingModeCombo->addItem(tr("Phong"), ShadingModePhong);
             m_shadingModeCombo->addItem(tr("Normal"), ShadingModeNormal);
         } else if (attrData.attributeType == Qt3DRender::QAttribute::IndexAttribute) {
@@ -478,6 +547,14 @@ void Qt3DGeometryTab::updateGeometry()
     m_geometryRenderer->setFirstInstance(0);
     m_geometryRenderer->setPrimitiveType(Qt3DRender::QGeometryRenderer::Triangles);
 
+    if (m_es2lineRenderer) {
+        m_es2lineRenderer->setInstanceCount(1);
+        m_es2lineRenderer->setIndexOffset(0);
+        m_es2lineRenderer->setFirstInstance(0);
+        m_es2lineRenderer->setPrimitiveType(Qt3DRender::QGeometryRenderer::LineLoop);
+        m_es2lineRenderer->setGeometry(geometry);
+    }
+
     auto oldGeometry = m_geometryRenderer->geometry();
     m_geometryRenderer->setGeometry(geometry);
     delete oldGeometry;
@@ -572,3 +649,34 @@ void Qt3DGeometryTab::trianglePicked(Qt3DRender::QPickEvent* pick)
     Q_UNUSED(pick);
 #endif
 }
+
+QSurfaceFormat Qt3DGeometryTab::probeFormat() const
+{
+    QSurfaceFormat format;
+    format.setDepthBufferSize(24);
+    format.setSamples(4); // ???
+    format.setStencilBufferSize(8); // ???
+
+    // try GL3 first
+    format.setRenderableType(QSurfaceFormat::OpenGL);
+    format.setMajorVersion(3);
+    format.setMinorVersion(0);
+    format.setProfile(QSurfaceFormat::CoreProfile);
+
+    QOpenGLContext context;
+    context.setScreen(window()->windowHandle()->screen());
+    context.setFormat(format);
+    if (context.create()) {
+        qDebug() << "Tried GL3, got:" << context.format() << context.format().renderableType();
+        m_usingES2Fallback = context.format().renderableType() == QSurfaceFormat::OpenGLES;
+        return format;
+    }
+
+    // fall back to ES2
+    m_usingES2Fallback = true;
+    format.setRenderableType(QSurfaceFormat::OpenGLES);
+    format.setMajorVersion(2);
+    format.setMinorVersion(0);
+    format.setProfile(QSurfaceFormat::NoProfile);
+    return format;
+}
