@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Tobias Koenig <tobias.koenig@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,6 +33,7 @@
 #include <QEvent>
 #include <QLayout>
 #include <QPainter>
+#include <QSplitter>
 
 using namespace GammaRay;
 
@@ -43,13 +44,19 @@ static QWidget *toplevelWidget(QWidget *widget)
     auto isTopLevel = [](QWidget *widget) {
         return widget->isWindow();
     };
+    auto lastSuitableParent = parent;
     while (parent->parentWidget() &&
             !isTopLevel(parent->parentWidget()) &&
             !isTopLevel(parent)) {
         parent = parent->parentWidget();
+
+        // don't pick parents that can't take the overlay as a children
+        if (!qobject_cast<QSplitter*>(parent)) {
+            lastSuitableParent = parent;
+        }
     }
 
-    return parent;
+    return lastSuitableParent;
 }
 
 OverlayWidget::OverlayWidget()
