@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,7 +32,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
 
     QWebView view;
-    view.setUrl(QUrl("http://www.kdab.com/gammaray"));
+    view.setUrl(QUrl("https://www.kdab.com/gammaray"));
     view.show();
 
     return app.exec();
